netapp_ontap.models.volume_protocol_raw_performance_stat_rw API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_protocol_raw_performance_stat_rw`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeProtocolRawPerformanceStatRwSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeProtocolRawPerformanceStatRw object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `count: Size GET`

    Number of operations of the given type performed on this volume.

    Example: 1000

  `total_time: Size GET`

    The raw data component latency in microseconds measured within ONTAP for all operations of the given type.

    Example: 200

  `volume_protocol_latency_histogram_counts: List[Size] GET`

    The volume_protocol_latency_histogram_counts field of the volume_protocol_raw_performance_stat_rw.

    Example: [0,0,0,0,0,15,35,100,200,200,300,500,500,500,1000,1000,800,500,500,300,200,50,40,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]

  `volume_protocol_latency_histogram_labels: List[str] GET`

    Labels for the latency histogram, ranging from <2us to >20s.

    Example: ["<2us","<6us","<10us","<14us","<20us","<40us","<60us","<80us","<100us","<200us","<400us","<600us","<800us","<1ms","<2ms","<4ms","<6ms","<8ms","<10ms","<12ms","<14ms","<16ms","<18ms","<20ms","<40ms","<60ms","<80ms","<100ms","<200ms","<400ms","<600ms","<800ms","<1s","<2s","<4s","<6s","<8s","<10s","<20s",">20s"]

  `volume_protocol_size_histogram_counts: List[Size] GET`

    The volume_protocol_size_histogram_counts field of the volume_protocol_raw_performance_stat_rw.

    Example: [2400,1055,1100,700,500,300,200,100,100,50,50,75,25,0,0]

  `volume_protocol_size_histogram_labels: List[str] GET`

    Labels for the size histogram, ranging from <4KB to >1024KB.

    Example: ["< 4KB","= 4KB","< 8KB","= 8KB","< 16KB","= 16KB","< 32KB","= 32KB","< 64KB","= 64KB","< 256KB","= 256KB","< 1024KB","= 1024KB","> 1024KB"]